@@ -10,7 +10,7 @@
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
-(defparameter *autoconf-host* "armv6l-unknown-linux-gnueabihf")
+(defparameter *autoconf-host* "armv6l-unknown-linux-gnueabi")
 ;; This variable is kept for backwards compatibiliy reasons:
 ;; We seem to be in the fortunate position that we sometimes need to check for windows.
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
